@@ -1,4 +1,4 @@
-// Partial SPL Token v2.0.x declarations inlined to avoid an external dependency on the spl-token crate
+// Partial SPL Token v2.0.x declarations inlined to avoid an external dependency on the safe-token crate
 solana_sdk::declare_id!("HMGr16f8Ct1Zeb9TGPypt9rPgzCkmhCQB8Not8vwiPW1");
 
 pub(crate) mod new_token_program {
@@ -31,7 +31,7 @@ pub mod state {
 }
 
 pub mod native_mint {
-    solana_sdk::declare_id!("So11111111111111111111111111111111111111112");
+    solana_sdk::declare_id!("Safe111111111111111111111111111111111111112");
 
     /*
         Mint {
